==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/VlanGroupPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.VlanGroupPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Vlan group properties.
 * @property name Vlan group name.
 * @property vlans List of vlans.
 */
public data class VlanGroupPropertiesArgs(
    public val name: Output<String>? = null,
    public val vlans: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.VlanGroupPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.managednetworkfabric.inputs.VlanGroupPropertiesArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.VlanGroupPropertiesArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .vlans(vlans?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [VlanGroupPropertiesArgs].
 */
@PulumiTagMarker
public class VlanGroupPropertiesArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var vlans: Output<List<String>>? = null

    /**
     * @param value Vlan group name.
     */
    @JvmName("krtqlxuxmlfxoopy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value List of vlans.
     */
    @JvmName("ilasttbkrrpovdrk")
    public suspend fun vlans(`value`: Output<List<String>>) {
        this.vlans = value
    }

    @JvmName("wtwqfonndouedirl")
    public suspend fun vlans(vararg values: Output<String>) {
        this.vlans = Output.all(values.asList())
    }

    /**
     * @param values List of vlans.
     */
    @JvmName("fxogbovdlqglesjd")
    public suspend fun vlans(values: List<Output<String>>) {
        this.vlans = Output.all(values)
    }

    /**
     * @param value Vlan group name.
     */
    @JvmName("pelxojbiandxbniw")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value List of vlans.
     */
    @JvmName("nwahguqpgqmtdxdt")
    public suspend fun vlans(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vlans = mapped
    }

    /**
     * @param values List of vlans.
     */
    @JvmName("nuroncqpxxgribwt")
    public suspend fun vlans(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vlans = mapped
    }

    internal fun build(): VlanGroupPropertiesArgs = VlanGroupPropertiesArgs(
        name = name,
        vlans = vlans,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/VlanGroupPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.VlanGroupPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Vlan group properties.
 * @property name Vlan group name.
 * @property vlans List of vlans.
 */
public data class VlanGroupPropertiesArgs(
    public val name: Output<String>? = null,
    public val vlans: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.VlanGroupPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.managednetworkfabric.inputs.VlanGroupPropertiesArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.VlanGroupPropertiesArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .vlans(vlans?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [VlanGroupPropertiesArgs].
 */
@PulumiTagMarker
public class VlanGroupPropertiesArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var vlans: Output<List<String>>? = null

    /**
     * @param value Vlan group name.
     */
    @JvmName("kkusjpewpvtrljya")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value List of vlans.
     */
    @JvmName("duliyckyluiaojpx")
    public suspend fun vlans(`value`: Output<List<String>>) {
        this.vlans = value
    }

    @JvmName("aurefeffqfubnpoy")
    public suspend fun vlans(vararg values: Output<String>) {
        this.vlans = Output.all(values.asList())
    }

    /**
     * @param values List of vlans.
     */
    @JvmName("fkxrptqhwjwgqorb")
    public suspend fun vlans(values: List<Output<String>>) {
        this.vlans = Output.all(values)
    }

    /**
     * @param value Vlan group name.
     */
    @JvmName("qrotwgekvqquhjos")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value List of vlans.
     */
    @JvmName("mmtmlcwofhgqtkqj")
    public suspend fun vlans(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vlans = mapped
    }

    /**
     * @param values List of vlans.
     */
    @JvmName("fuxhsfbesjktkwcw")
    public suspend fun vlans(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vlans = mapped
    }

    internal fun build(): VlanGroupPropertiesArgs = VlanGroupPropertiesArgs(
        name = name,
        vlans = vlans,
    )
}
